@@ -7,7 +7,7 @@
 #include "muscle.h"
 #include <stdio.h>
 
-#include "msa.h"
+#include "msa.h" // Added for R port.
 
 #ifdef	WIN32
 #include <windows.h>	// for SetPriorityClass()
@@ -17,7 +17,11 @@
 #endif
 
 
+// For R.
 #include <R.h>
+#include <Rinternals.h>
+#include <R_ext/Rdynload.h>
+
 
 
 const char *MUSCLE_LONG_VERSION	= "MUSCLE v" SHORT_VERSION "."
@@ -53,8 +57,13 @@ void muscleR(int *argc, char **argv)
 
 	SetNewHandler();
 	SetStartTime();
+
+	default_params();
+	blank_params();
+
 	ProcessArgVect(nargs, argv);
 	SetParams();
+
 	SetLogFile();
 
 	//extern void TestSubFams(const char *);
@@ -95,5 +104,34 @@ void muscleR(int *argc, char **argv)
 	}
 
 
+// Register the native code in R.
+
+R_CMethodDef cMethods[] = {
+   {"muscleR", (DL_FUNC) &muscleR, 2},
+   NULL
+};
+
+
+
+void R_init_muscle(DllInfo *info)
+{
+   R_registerRoutines(info, cMethods, NULL, NULL, NULL);
 }
 
+
+}
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
